@@ -42,6 +42,7 @@ def _get_cookie_data(oauth2_cookie_config, cookie_data):
     _cookie_signer = _get_signer(oauth2_cookie_config)
     _cookie_max_age = _get_max_age(oauth2_cookie_config)
     try:
+        _cookie_data = cookie_data.encode('utf-8')
         _cookie_data = _cookie_signer.unsign(cookie_data, _cookie_max_age)
         _cookie_data = json.loads(b64decode(_cookie_data))
     except (BadSignature, Exception) as e:
@@ -53,7 +54,7 @@ def _get_state_cookie(config, state, req_uri):
     _cookie_content = {'state': state, 'type': 'state', 'request_uri': req_uri}
     data = b64encode(json.dumps(_cookie_content).encode('utf-8'))
     data = _get_signer(config).sign(data)
-    return data
+    return data.decode('utf-8')
 
 
 async def process(config, scope: Scope, receive: Receive, send: Send) -> None:
@@ -66,38 +67,38 @@ async def process(config, scope: Scope, receive: Receive, send: Send) -> None:
         if len(_uri_index) > 0:
             oauth2_cookie_path = oauth2_cookie_config['uris'][_uri_index[0]]
             oauth2_cookie_config = oauth2_cookie_config['config']
-            # TODO: get path
             http_connection = HTTPConnection(scope)
 
             # do we have a cookie?
             if oauth2_cookie_name in http_connection.cookies:
-                _cookie_data = _get_cookie_data(
-                    oauth2_cookie_config, http_connection.cookies[oauth2_cookie_name].encode('utf-8')
-                )
+                _cookie_data = _get_cookie_data(oauth2_cookie_config, http_connection.cookies[oauth2_cookie_name])
 
                 _cookie_type = _cookie_data.get('type')
                 if _cookie_type is not None:
                     if _cookie_type == 'state':
                         # its a state cookie > do oauth2 code_grant req
                         i = 0
-                    if _cookie_type == 'bla':
+                    if _cookie_type == 'token':
                         # real cookie w/ auth data
-                        cookie_data.update({oauth2_cookie_name: _cookie_data})
-                else:
-                    # defect cookie / not our cookie > try again?
-                    pass
+                        cookie_data.update({oauth2_cookie_name: _cookie_data.get('token')})
+                # else:
+                #     # defect cookie / not our cookie > try again?
+                #     pass
             else:
                 # no cookie > do oauth2 redirect
                 _request = Request(scope, receive)
+                _redirect_uri = f"{_request.base_url}{oauth2_cookie_path}"
+                if oauth2_cookie_config.get('redirect_uri') is not None:
+                    _redirect_uri = oauth2_cookie_config.get('redirect_uri')
                 _client = OAuth2Session(
                     client_id=oauth2_cookie_config['client_id'],
-                    redirect_uri=oauth2_cookie_path
+                    redirect_uri=_redirect_uri
                 )
                 _auth_url, state = _client.authorization_url(f"{oauth2_cookie_config['idp']}/authorize")
                 response = RedirectResponse(_auth_url, status_code=307)
                 response.set_cookie(
                     key=oauth2_cookie_name, value=_get_state_cookie(oauth2_cookie_config, state, str(_request.url)),
-                    secure=True, samesite='none', httponly=True, expires='session'
+                    secure=True, samesite='none', httponly=True, expires='session', # path=oauth2_cookie_path
                 )
                 return response(scope, receive, send)
 
